# JSON Schema for Humans configuration file

Type: object

Choose how to generate JSON Schema for Humans documentation file.

Configuration parameters can be provided in several ways:

- On the CLI using `--config parameter_name=value` (example: `--config template_name=flat`)
- On the CLI using a config file `--config-file config.json`
- From code, by providing a GenerationConfiguration object to the called generation method.

##

Type: boolean Default: true

Minify the output HTML document.

##

Type: boolean Default: true

Whether to consider the description as markdown and render it accordingly

##

Type: boolean Default: false

Add an `Expand all` and a `Collapse all` button at the top of the generated documentation

##

Type: boolean Default: true

If a description is considered big, show only the beginning and add a `Read more` button.

##

Type: boolean Default: true

If several `$ref` points to the same definition, only render the documentation for this definition the first time. All other occurrences are replaced by an anchor link to the first occurrence. The first occurrence is the one that is the least nested from the top of the schema and appears first in that nesting level.

Note: If this option is off and the schema contains recursive definitions, the generation will crash!

##

Type: integer Default: 25

Advanced option
If `link_to_reused_ref` is false and a `$ref` in the schema refers to a parent of itself, we would get a `RecursionError` trying to render the documentation. To avoid this, each reference is checked for circular references.

This option determines the number of times to recursively follow definitions looking for a circular reference.

In other words, if a schema has a deeply nested element that refers to itself, this option may need to be increased.

##

Type: boolean Default: false

Mark a property as deprecated (with a big red badge) if the description contains the string `[Deprecated`

##

Type: boolean Default: false

Extract the default value of a property from the description like this: `[Default `the_default_value`]`.

The default value from the "default" attribute will be used in priority

##

Type: boolean Default: true

Copy `schema_doc.css` to the same directory as `RESULT_FILE` after generation

##

Type: boolean Default: true

Copy `schema_doc.min.js` to the same directory as `RESULT_FILE` after generation.

This file contains the logic for the anchor links

##

Type: enum (of string) Default: "js"

The HTML templates to use to render the documentation.

`js` is the default one, it uses javascript for anchor links, collapsible sections and tabs. `flat` uses no javascript, but has no interactivity.

#### Must be one of:

- "flat"
- "js"

##

Type: object Default: {"fenced-code-blocks": {"break-on-newline": true, "cssclass": "highlight jumbotron", "tables": null}, "tables": null}

Markdown 2 options for the descriptions. `description_is_markdown` must be true for this to have any effect.

WARNING
Adding an extra, even if the value is false, will activate it. For example `{"break-on-newline": false}` will activate the `break-on-newline` extra.

Example:

    {
        "fenced-code-blocks": {
            "cssclass": "highlight jumbotron"
        },
        "tables": null,
        "break-on-newline": true,
        "cuddled-lists": true
    }